Crate hashtree_cli

Crate hashtree_cli 

Re-exports

pub use config::Config;
pub use eviction::spawn_background_eviction_task;
pub use eviction::BACKGROUND_EVICTION_INTERVAL;
pub use fetch::FetchConfig;
pub use fetch::Fetcher;
pub use server::HashtreeServer;
pub use storage::CachedRoot;
pub use storage::HashtreeStore;
pub use storage::StorageByPriority;
pub use storage::TreeMeta;
pub use storage::PRIORITY_FOLLOWED;
pub use storage::PRIORITY_OTHER;
pub use storage::PRIORITY_OWN;
pub use sync::BackgroundSync;
pub use sync::SyncConfig;
pub use sync::SyncPriority;
pub use sync::SyncStatus;
pub use sync::SyncTask;

Modules

cashu_helper
config
daemon
eviction
fetch
Remote content fetching with WebRTC and Blossom fallback
ignore_rules
nostr_mirror
nostr_relay
p2p_common
server
socialgraph
storage
sync
Background sync service for auto-pulling trees from Nostr
webrtc
Native mesh connectivity for hashtree data exchange.

Structs

BluetoothConfig
Configuration for the optional Bluetooth peer transport.
NostrKeys
Nostr keys
NostrResolverConfig
Configuration for NostrRootResolver
NostrRootResolver
NostrRootResolver - Maps npub/treename keys to merkle root hashes
PeerId
Unique identifier for a peer in the network
PoolConfig
Settings for a peer pool
PoolSettings
Pool settings for both pools
ResolverEntry
Entry in a resolver list
WebRTCConfig
WebRTCManager
Native mesh manager handles peer discovery and transport fan-out.
WebRTCState
Shared state for the native mesh router.

Enums

BluetoothBackendState
ConnectionState
Connection state for a peer.
DataMessage
Parsed data message
PeerPool
Peer pool classification
ResolverError
Errors that can occur during resolution

Traits

ContentStore
Trait for content storage that can be used by WebRTC peers
LocalNostrBus
NostrToBech32
RootResolver
RootResolver - Maps human-readable keys to content identifiers (Cid)

Type Aliases

PeerClassifier
Callback type for classifying peers into pools
SharedLocalNostrBus