pub struct ServerConfig {Show 14 fields
pub bind_address: String,
pub enable_auth: bool,
pub stun_port: u16,
pub enable_webrtc: bool,
pub enable_multicast: bool,
pub multicast_group: String,
pub multicast_port: u16,
pub max_multicast_peers: usize,
pub enable_wifi_aware: bool,
pub max_wifi_aware_peers: usize,
pub enable_bluetooth: bool,
pub max_bluetooth_peers: usize,
pub public_writes: bool,
pub socialgraph_snapshot_public: bool,
}Fields
bind_address: Stringenable_auth: boolstun_port: u16Port for the built-in STUN server (0 = disabled)
enable_webrtc: boolEnable WebRTC P2P connections
enable_multicast: boolEnable LAN multicast discovery/signaling for native peers.
multicast_group: StringIPv4 multicast group used for LAN discovery/signaling.
multicast_port: u16UDP port used for LAN multicast discovery/signaling.
max_multicast_peers: usizeMaximum peers admitted from LAN multicast discovery. Set to 0 to disable multicast even when enable_multicast is true.
enable_wifi_aware: boolEnable Android Wi-Fi Aware nearby discovery/signaling for native peers.
max_wifi_aware_peers: usizeMaximum peers admitted from Wi-Fi Aware discovery. Set to 0 to disable Wi-Fi Aware even when enable_wifi_aware is true.
enable_bluetooth: boolEnable native Bluetooth discovery/transport for nearby peers.
max_bluetooth_peers: usizeMaximum peers admitted from Bluetooth discovery. Set to 0 to disable Bluetooth even when enable_bluetooth is true.
public_writes: boolAllow anyone with valid Nostr auth to write (default: true) When false, only social graph members can write
Allow public access to social graph snapshot endpoint (default: false)