Module storage

Module storage 

Structs

AddProgress
AddProgressSnapshot
BlobMetadata
Blob metadata for Blossom protocol
CachedRoot
Cached root info from Nostr events.
CompactResult
DirEntry
DirectoryListing
FileChunkMetadata
FileRangeChunksOwned
Owned iterator for async streaming
GcStats
HashtreeStore
LocalStoreStats
Storage statistics
OwnedBlobStats
PinTreeResult
Result of atomically indexing and pinning a complete DAG.
PinnedItem
PoolReadFallbackStatus
Public status for one temporary read-only Pool fallback.
PoolStoreWithFallbacks
A PoolStore with temporary exact-hash lookup fallbacks used during an online migration from the former hot and legacy LMDB tiers.
ProfileRepairRetentionLease
ProfileRepairRetentionPublicationGuard
R2ImportOptions
R2ImportResult
ReadOnlyPoolStoreWithFallbacks
A strict MDB_RDONLY PoolStore plus strict read-only legacy fallbacks.
RootRetentionReport
StorageByPriority
Storage usage broken down by priority tier
StorageRouter
Storage router - local store primary with optional S3 backup
StorageStats
TreeIndexLimits
Resource limits for validating and indexing a complete pinned DAG.
TreeMeta
Metadata for a synced tree (for eviction tracking)
VerifyResult
Result of blob integrity verification

Enums

LocalStore
Local blob store - wraps either FsBlobStore or LmdbBlobStore
PinTreeError

Constants

LOCAL_ADD_EXTERNAL_BLOB_DIR_NAME
PRIORITY_FOLLOWED
PRIORITY_OTHER
Priority levels for tree eviction
PRIORITY_OWN
PROFILE_REPAIR_RETENTION_LEASE_FORMAT
PROFILE_REPAIR_RETENTION_LEASE_RELATIVE_PATH

Functions

acquire_existing_profile_repair_retention_guard
Acquire the existing retention-root publication lock without creating any path or opening the application blob writer.
compact_lmdb_environments_under