NostrKeys

Struct NostrKeys 

pub struct NostrKeys {
    pub public_key: PublicKey,
    /* private fields */
}
Nostr keys

Fields

public_key: PublicKey

Public key

Implementations

Source

impl Keys

pub fn vanity<S>( prefixes: Vec<S>, bech32: bool, num_cores: usize, ) -> Result<Keys, Error>
where S: Into<String>,

Generate new vanity public key

Source

impl Keys

pub fn new(secret_key: SecretKey) -> Keys

Initialize nostr keys from secret key.

This method internally construct the Keypair and derive the PublicKey.

pub fn new_with_ctx<C>(secp: &Secp256k1<C>, secret_key: SecretKey) -> Keys
where C: Signing,

Initialize nostr keys from secret key.

This method internally construct the Keypair and derive the PublicKey.

pub fn parse<S>(secret_key: S) -> Result<Keys, Error>
where S: AsRef<str>,

Parse secret key from hex or bech32 and compose keys

pub fn parse_with_ctx<C, S>( secp: &Secp256k1<C>, secret_key: S, ) -> Result<Keys, Error>
where C: Signing, S: AsRef<str>,

Parse secret key from hex or bech32 and compose keys

pub fn generate() -> Keys

Generate random keys

This constructor use a random number generator that retrieves randomness from the operating system (see OsRng).

Use Keys::generate_with_rng to specify a custom random source.

Check Keys::generate_with_ctx to learn more about how this constructor works internally.

pub fn generate_with_rng<R>(rng: &mut R) -> Keys
where R: Rng + ?Sized,

Generate random keys using a custom random source

Check Keys::generate_with_ctx to learn more about how this constructor works internally.

pub fn generate_with_ctx<C, R>(secp: &Secp256k1<C>, rng: &mut R) -> Keys
where C: Signing, R: Rng + ?Sized,

Generate random keys

Generate random keys without construct the Keypair. This allows faster keys generation (i.e. for vanity pubkey mining). The Keypair will be automatically created when needed and stored in a cell.

pub fn generate_without_keypair_with_ctx<C, R>( secp: &Secp256k1<C>, rng: &mut R, ) -> Keys
where C: Signing, R: Rng + ?Sized,

👎Deprecated since 0.35.0: Use generate_with_ctx instead
pub fn generate_without_keypair<R>(rng: &mut R) -> Keys
where R: Rng + ?Sized,

👎Deprecated since 0.35.0: Use generate or generate_with_rng instead
pub fn public_key(&self) -> PublicKey

Get public key

pub fn public_key_ref(&self) -> &PublicKey

👎Deprecated since 0.35.0

Get public key

pub fn secret_key(&self) -> &SecretKey

Get secret key

pub fn key_pair<C>(&self, secp: &Secp256k1<C>) -> &Keypair
where C: Signing,

Get keypair

pub fn sign_schnorr(&self, message: &Message) -> Signature

Creates a schnorr signature of the Message.

This method use a random number generator that retrieves randomness from the operating system (see OsRng).

pub fn sign_schnorr_with_ctx<C, R>( &self, secp: &Secp256k1<C>, message: &Message, rng: &mut R, ) -> Signature
where C: Signing, R: Rng + CryptoRng,

Creates a schnorr signature of the Message using a custom random number generation source.