pub trait ContentStore:
Send
+ Sync
+ 'static {
// Required method
fn get(&self, hash_hex: &str) -> Result<Option<Vec<u8>>, Error>;
}Expand description
Trait for content storage that can be used by WebRTC peers
pub trait ContentStore:
Send
+ Sync
+ 'static {
// Required method
fn get(&self, hash_hex: &str) -> Result<Option<Vec<u8>>, Error>;
}Trait for content storage that can be used by WebRTC peers