pub struct KnownPeerSnapshot {
pub version: u32,
pub peers: Vec<KnownPeerRecord>,
}Expand description
Snapshot of private peer signaling hints learned over established peer links.
Fields
version: u32peers: Vec<KnownPeerRecord>Trait Implementations
Sourceimpl Clone for KnownPeerSnapshot
impl Clone for KnownPeerSnapshot
Sourcefn clone(&self) -> KnownPeerSnapshot
fn clone(&self) -> KnownPeerSnapshot
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for KnownPeerSnapshot
impl Debug for KnownPeerSnapshot
Sourceimpl Default for KnownPeerSnapshot
impl Default for KnownPeerSnapshot
Sourcefn default() -> KnownPeerSnapshot
fn default() -> KnownPeerSnapshot
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for KnownPeerSnapshot
impl<'de> Deserialize<'de> for KnownPeerSnapshot
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<KnownPeerSnapshot, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<KnownPeerSnapshot, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for KnownPeerSnapshot
impl PartialEq for KnownPeerSnapshot
Sourcefn eq(&self, other: &KnownPeerSnapshot) -> bool
fn eq(&self, other: &KnownPeerSnapshot) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for KnownPeerSnapshot
impl Serialize for KnownPeerSnapshot
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Eq for KnownPeerSnapshot
impl StructuralPartialEq for KnownPeerSnapshot