pub struct Peer {
pub peer_id: PeerId,
pub direction: PeerDirection,
pub created_at: Instant,
pub connected_at: Option<Instant>,
pub data_channel: Arc<Mutex<Option<Arc<RTCDataChannel>>>>,
pub pending_requests: Arc<Mutex<HashMap<String, PendingRequest>>>,
/* private fields */
}Expand description
WebRTC peer connection with data channel protocol
Fields
peer_id: PeerIddirection: PeerDirectioncreated_at: Instantconnected_at: Option<Instant>data_channel: Arc<Mutex<Option<Arc<RTCDataChannel>>>>Data channel - can be set from callback when receiving channel from peer
pending_requests: Arc<Mutex<HashMap<String, PendingRequest>>>Implementations
Sourceimpl Peer
impl Peer
Sourcepub async fn new(
peer_id: PeerId,
direction: PeerDirection,
my_peer_id: PeerId,
signaling_tx: Sender<SignalingMessage>,
stun_servers: Vec<String>,
) -> Result<Self>
pub async fn new( peer_id: PeerId, direction: PeerDirection, my_peer_id: PeerId, signaling_tx: Sender<SignalingMessage>, stun_servers: Vec<String>, ) -> Result<Self>
Create a new peer connection
Sourcepub async fn new_with_store(
peer_id: PeerId,
direction: PeerDirection,
my_peer_id: PeerId,
signaling_tx: Sender<SignalingMessage>,
stun_servers: Vec<String>,
store: Option<Arc<dyn ContentStore>>,
) -> Result<Self>
pub async fn new_with_store( peer_id: PeerId, direction: PeerDirection, my_peer_id: PeerId, signaling_tx: Sender<SignalingMessage>, stun_servers: Vec<String>, store: Option<Arc<dyn ContentStore>>, ) -> Result<Self>
Create a new peer connection with content store
Sourcepub fn set_store(&mut self, store: Arc<dyn ContentStore>)
pub fn set_store(&mut self, store: Arc<dyn ContentStore>)
Set content store
Sourcepub fn state(&self) -> RTCPeerConnectionState
pub fn state(&self) -> RTCPeerConnectionState
Get connection state
Sourcepub fn signaling_state(&self) -> RTCSignalingState
pub fn signaling_state(&self) -> RTCSignalingState
Get signaling state
Sourcepub fn is_connected(&self) -> bool
pub fn is_connected(&self) -> bool
Check if connected
pub fn htl_config(&self) -> &PeerHTLConfig
Sourcepub async fn setup_handlers(&self) -> Result<()>
pub async fn setup_handlers(&self) -> Result<()>
Setup event handlers for the peer connection
Sourcepub async fn connect(&self) -> Result<Value>
pub async fn connect(&self) -> Result<Value>
Initiate connection (create offer) - for outbound connections
Sourcepub async fn handle_offer(&self, offer: Value) -> Result<Value>
pub async fn handle_offer(&self, offer: Value) -> Result<Value>
Handle incoming offer and create answer
Sourcepub async fn handle_answer(&self, answer: Value) -> Result<()>
pub async fn handle_answer(&self, answer: Value) -> Result<()>
Handle incoming answer
Sourcepub async fn handle_candidate(&self, candidate: Value) -> Result<()>
pub async fn handle_candidate(&self, candidate: Value) -> Result<()>
Handle incoming ICE candidate
Sourcepub fn has_data_channel(&self) -> bool
pub fn has_data_channel(&self) -> bool
Check if data channel is ready
Sourcepub async fn request(&self, hash_hex: &str) -> Result<Option<Vec<u8>>>
pub async fn request(&self, hash_hex: &str) -> Result<Option<Vec<u8>>>
Request content by hash from this peer
Sourcepub async fn request_with_timeout(
&self,
hash_hex: &str,
timeout: Duration,
) -> Result<Option<Vec<u8>>>
pub async fn request_with_timeout( &self, hash_hex: &str, timeout: Duration, ) -> Result<Option<Vec<u8>>>
Request content by hash from this peer with an explicit timeout.
Sourcepub async fn query_nostr_events(
&self,
filters: Vec<NostrFilter>,
timeout: Duration,
) -> Result<Vec<Event>>
pub async fn query_nostr_events( &self, filters: Vec<NostrFilter>, timeout: Duration, ) -> Result<Vec<Event>>
Query a peer’s embedded Nostr relay over the WebRTC data channel. Returns all events received before EOSE/timeout.
Sourcepub async fn send_mesh_frame_text(&self, frame: &MeshNostrFrame) -> Result<()>
pub async fn send_mesh_frame_text(&self, frame: &MeshNostrFrame) -> Result<()>
Send a mesh signaling frame as text over the data channel.
Sourcepub async fn send_message(&self, msg: &DataMessage) -> Result<()>
pub async fn send_message(&self, msg: &DataMessage) -> Result<()>
Send a message over the data channel