Canonical Hashtree mesh wire types. The non-WebRTC build re-exports the same codec instead of maintaining a second framing implementation.
Structs
- Data
Chunk - Quoted data chunk delivered after payment negotiation.
- Data
Payment - Payment message body for chunk-by-chunk settlement.
- Data
Payment Ack - Payment acknowledgement for quoted chunk settlement.
- Data
Quote Request - Quote request message body
- Data
Quote Response - Quote response message body
- Data
Request - Data request message body
- Data
Response - Data response message body
- Peer
Hints - Private signaling hints exchanged over an established peer link.
- Pubsub
Frame - Pubsub data frame delivered over mesh peer links.
- Pubsub
Interest - Pubsub interest advertisement.
- Pubsub
Inventory - Pubsub inventory announcement for inventory-first delivery.
- Pubsub
Want - Pubsub want request for inventory-first delivery.
Enums
- Data
Message - Parsed data message
Constants
- MAX_HTL
- Default HTL (Hops To Live) budget for mesh blob retrieval.
Functions
- encode_
chunk - Encode a quoted data chunk to wire format.
- encode_
payment - Encode a payment message to wire format.
- encode_
payment_ ack - Encode a payment acknowledgement to wire format.
- encode_
peer_ hints - Encode private peer hints to wire format.
- encode_
pubsub_ frame - Encode a pubsub data frame to wire format.
- encode_
pubsub_ interest - Encode a pubsub interest to wire format.
- encode_
pubsub_ inventory - Encode a pubsub inventory announcement to wire format.
- encode_
pubsub_ want - Encode a pubsub want request to wire format.
- encode_
quote_ request - Encode a quote request message to wire format.
- encode_
quote_ response - Encode a quote response message to wire format.
- encode_
request - Encode a request message to wire format Uses named/map encoding for compatibility with hashtree-ts and to support optional fields
- encode_
response - Encode a response message to wire format Uses named/map encoding for compatibility with hashtree-ts and to support optional fields
- parse_
message - Parse a wire format message