pub struct NostrConfig {
pub enabled: bool,
pub relays: Vec<String>,
pub allowed_npubs: Vec<String>,
pub socialgraph_root: Option<String>,
pub social_graph_crawl_depth: u32,
pub max_write_distance: u32,
pub db_max_size_gb: u64,
pub spambox_max_size_gb: u64,
pub negentropy_only: bool,
pub mirror_kinds: Vec<u16>,
pub history_sync_author_chunk_size: usize,
pub history_sync_on_reconnect: bool,
}Fields
enabled: boolrelays: Vec<String>allowed_npubs: Vec<String>List of npubs allowed to write (blossom uploads). If empty, uses public_writes setting.
Social graph root pubkey (npub). Defaults to own key if not set.
How many hops to crawl the social graph (default: 2)
max_write_distance: u32Max follow distance for write access (default: 3)
db_max_size_gb: u64Max size for the trusted social graph store in GB (default: 10)
spambox_max_size_gb: u64Max size for the social graph spambox in GB (default: 1) Set to 0 for memory-only spambox (no on-disk DB)
negentropy_only: boolRequire relays to support NIP-77 negentropy for mirror history sync.
mirror_kinds: Vec<u16>Kinds mirrored from upstream relays for the trusted hashtree index.
How many graph authors to reconcile before checkpointing the mirror root.
history_sync_on_reconnect: boolRun a catch-up history sync after relay reconnects.
Implementations
Sourceimpl NostrConfig
impl NostrConfig
pub fn active_relays(&self) -> Vec<String>