pub struct ServerConfig {
pub bind_address: String,
pub enable_auth: bool,
pub stun_port: u16,
pub enable_webrtc: bool,
pub public_writes: bool,
pub socialgraph_snapshot_public: bool,
}Fields
bind_address: Stringenable_auth: boolstun_port: u16Port for the built-in STUN server (0 = disabled)
enable_webrtc: boolEnable WebRTC P2P connections
public_writes: boolAllow anyone with valid Nostr auth to write (default: true) When false, only social graph members can write
Allow public access to social graph snapshot endpoint (default: false)