Nostrdb integration for social graph-based access control and peer classification.
Re-exports
pub use access::SocialGraphAccessControl;pub use crawler::SocialGraphCrawler;
Modules
- access
- Social graph-based write access control using nostrdb.
- crawler
- Social graph crawler - BFS crawl of follow lists via Nostr relays.
- snapshot
Structs
- Ndb
- A nostrdb context. Construct one of these with Ndb::new.
- Social
Graph Stats - Social graph statistics
Functions
- get_
follow_ distance - Get the follow distance for a pubkey from the social graph root. Returns None if the pubkey is not in the social graph.
- get_
follows - Get the list of pubkeys that a given pubkey follows.
- ingest_
event - Ingest a Nostr event JSON string into nostrdb_social. Wraps the event in relay format: [“EVENT”,“sub_id”,{…}]
- init_
ndb - Initialize nostrdb_social with the given data directory.
- init_
ndb_ at_ path - Initialize nostrdb_social at a specific directory (used for spambox).
- init_
ndb_ with_ mapsize - Initialize nostrdb_social with optional mapsize (bytes).
- is_
overmuted - Check if a user is overmuted based on muters vs followers at the closest distance where there is any opinion. Mirrors nostr-social-graph logic.
- set_
social_ graph_ root - Set the social graph root pubkey.