pub struct AppState {
pub store: Arc<HashtreeStore>,
pub auth: Option<AuthCredentials>,
pub webrtc_peers: Option<Arc<WebRTCState>>,
pub ws_relay: Arc<WsRelayState>,
pub max_upload_bytes: usize,
pub public_writes: bool,
pub allowed_pubkeys: HashSet<String>,
pub upstream_blossom: Vec<String>,
pub social_graph: Option<Arc<SocialGraphAccessControl>>,
pub nostr_relay: Option<Arc<NostrRelay>>,
}Fields
store: Arc<HashtreeStore>auth: Option<AuthCredentials>webrtc_peers: Option<Arc<WebRTCState>>WebRTC peer state for forwarding requests to connected P2P peers
ws_relay: Arc<WsRelayState>WebSocket relay state for /ws clients
max_upload_bytes: usizeMaximum upload size in bytes for Blossom uploads (default: 5 MB)
public_writes: boolAllow anyone with valid Nostr auth to write (default: true) When false, only allowed_pubkeys can write
allowed_pubkeys: HashSet<String>Pubkeys allowed to write (hex format, from config allowed_npubs)
upstream_blossom: Vec<String>Upstream Blossom servers for cascade fetching
Social graph access control (nostrdb-backed when feature enabled)
nostr_relay: Option<Arc<NostrRelay>>Nostr relay state for /ws and WebRTC Nostr messages