validate_profile_indexes_read_only

Function validate_profile_indexes_read_only 

pub async fn validate_profile_indexes_read_only<S: Store>(
    data_dir: &Path,
    store: Arc<S>,
    event: &Event,
) -> Result<StoredProfileSearchEntry>
Validate both profile indexes against one real metadata event using only a caller-provided blob store. This does not open or mutate the social graph.