pub struct NostrKeys {
pub public_key: PublicKey,
/* private fields */
}Expand description
Nostr keys
Fields
public_key: PublicKeyPublic key
Implementations
Sourceimpl Keys
impl Keys
Sourcepub fn parse<S>(secret_key: S) -> Result<Keys, Error>
pub fn parse<S>(secret_key: S) -> Result<Keys, Error>
Parse secret key from hex or bech32 and compose keys
Sourcepub fn parse_with_ctx<C, S>(
secp: &Secp256k1<C>,
secret_key: S,
) -> Result<Keys, Error>
pub fn parse_with_ctx<C, S>( secp: &Secp256k1<C>, secret_key: S, ) -> Result<Keys, Error>
Parse secret key from hex or bech32 and compose keys
Sourcepub fn generate() -> Keys
pub fn generate() -> Keys
Generate random keys
This constructor use a random number generator that retrieves randomness from the operating system (see OsRng).
Use Keys::generate_with_rng to specify a custom random source.
Check Keys::generate_with_ctx to learn more about how this constructor works internally.
Sourcepub fn generate_with_rng<R>(rng: &mut R) -> Keys
pub fn generate_with_rng<R>(rng: &mut R) -> Keys
Generate random keys using a custom random source
Check Keys::generate_with_ctx to learn more about how this constructor works internally.
Sourcepub fn generate_with_ctx<C, R>(secp: &Secp256k1<C>, rng: &mut R) -> Keys
pub fn generate_with_ctx<C, R>(secp: &Secp256k1<C>, rng: &mut R) -> Keys
Sourcepub fn generate_without_keypair_with_ctx<C, R>(
secp: &Secp256k1<C>,
rng: &mut R,
) -> Keys
👎Deprecated since 0.35.0: Use generate_with_ctx instead
pub fn generate_without_keypair_with_ctx<C, R>( secp: &Secp256k1<C>, rng: &mut R, ) -> Keys
generate_with_ctx insteadReplaced by Keys::generate_with_ctx
Sourcepub fn generate_without_keypair<R>(rng: &mut R) -> Keys
👎Deprecated since 0.35.0: Use generate or generate_with_rng instead
pub fn generate_without_keypair<R>(rng: &mut R) -> Keys
generate or generate_with_rng insteadReplaced by Keys::generate_with_rng
Sourcepub fn public_key(&self) -> PublicKey
pub fn public_key(&self) -> PublicKey
Get public key
Sourcepub fn public_key_ref(&self) -> &PublicKey
👎Deprecated since 0.35.0
pub fn public_key_ref(&self) -> &PublicKey
Get public key
Sourcepub fn secret_key(&self) -> &SecretKey
pub fn secret_key(&self) -> &SecretKey
Get secret key
Sourcepub fn sign_schnorr(&self, message: &Message) -> Signature
pub fn sign_schnorr(&self, message: &Message) -> Signature