pub struct NostrRootResolver { /* private fields */ }Expand description
NostrRootResolver - Maps npub/treename keys to merkle root hashes
Implementations
Sourceimpl NostrRootResolver
impl NostrRootResolver
Sourcepub async fn new(
config: NostrResolverConfig,
) -> Result<NostrRootResolver, ResolverError>
pub async fn new( config: NostrResolverConfig, ) -> Result<NostrRootResolver, ResolverError>
Create a new NostrRootResolver
Sourcepub fn pubkey(&self) -> Option<PublicKey>
pub fn pubkey(&self) -> Option<PublicKey>
Get current user’s public key (if we have a secret key)
Sourcepub fn filter_for_key(key: &str) -> Result<Filter, ResolverError>
pub fn filter_for_key(key: &str) -> Result<Filter, ResolverError>
Build the exact Nostr filter for a resolver key without opening a relay connection. Pubsub transports can use this to subscribe on behalf of the resolver.
Sourcepub fn event_matches_key(
key: &str,
event: &Event,
) -> Result<bool, ResolverError>
pub fn event_matches_key( key: &str, event: &Event, ) -> Result<bool, ResolverError>
Validate that a signed event is a usable root for exactly this key.
Pubsub consumers can use this before caching an event obtained from an untrusted transport. Private roots require resolver keys and therefore are not considered usable by this transport-neutral check.
Sourcepub async fn ingest_event(&self, event: Event) -> Result<bool, ResolverError>
pub async fn ingest_event(&self, event: Event) -> Result<bool, ResolverError>
Ingest a signed root event obtained from any transport. Returns true only when it advances the replaceable root for its author and tree.
Sourcepub async fn resolve_wait(&self, key: &str) -> Result<Cid, ResolverError>
pub async fn resolve_wait(&self, key: &str) -> Result<Cid, ResolverError>
Resolve a key, waiting indefinitely until found.
Unlike resolve() which returns None after timeout, this method
subscribes and waits until a Cid is found. Caller should apply their
own timeout if needed (e.g., via tokio::time::timeout).
This matches the behavior of hashtree-ts NostrRootResolver.
Sourcepub async fn publish_private(
&self,
key: &str,
cid: &Cid,
) -> Result<bool, ResolverError>
pub async fn publish_private( &self, key: &str, cid: &Cid, ) -> Result<bool, ResolverError>
Publish a private root (selfEncryptedKey tag, NIP-44 to self)