NostrRootResolver

Struct NostrRootResolver 

pub struct NostrRootResolver { /* private fields */ }
NostrRootResolver - Maps npub/treename keys to merkle root hashes

Implementations

Source

impl NostrRootResolver

pub async fn new( config: NostrResolverConfig, ) -> Result<NostrRootResolver, ResolverError>

Create a new NostrRootResolver

pub fn pubkey(&self) -> Option<PublicKey>

Get current user’s public key (if we have a secret key)

pub async fn resolve_wait(&self, key: &str) -> Result<Cid, ResolverError>

Resolve a key, waiting indefinitely until found.

Unlike resolve() which returns None after timeout, this method subscribes and waits until a Cid is found. Caller should apply their own timeout if needed (e.g., via tokio::time::timeout).

This matches the behavior of hashtree-ts NostrRootResolver.

pub async fn publish_private( &self, key: &str, cid: &Cid, ) -> Result<bool, ResolverError>

Publish a private root (selfEncryptedKey tag, NIP-44 to self)